package com.aks.ejb30;

/**
 * This will also import all annotations defined in EJB3.0 specification.
 */
import javax.ejb.*;


/**
 * An Entity Bean indicating that container should access its persistent
 * fields directly - all fields must be protected or public.
 */
@Entity(access=FIELD)
public class Customer {
	/**
	 * Container should auto-generate primary key 'id'. generate=AUTO
	 * lets the container pick appropriate auto-generation strategy.
	 * Containers might just let the administrator define a default.
	 */
	@Id(generate=AUTO)
	protected Long id;

	/**
	 * Version annotation provides support for optimistic concurrency control.
	 */
	@Version
	protected int version;

	/**
	 * Customer has a Many-to-One relationship with Address Entity
	 */
	@ManyToOne
	protected Address address;

	/**
	 * The simplest mechanism for mapping a persistent field to a DB column.
	 */
	@Basic(fetch=EAGER)
	protected String description;

	/**
	 * Customer has a One-to-Many relationship with Order Entity.
	 */
	@OneToMany(targetEntity="com.aks.ejb30.Order")
	protected Collection orders = new Vector();
}